@@ -108,7 +108,7 @@ where
     const TARGET: &str = "patch";
     let mut write_to_sink = |topic: &str, data: &str| -> Result<()> {
         log::trace!(target: TARGET, "w<{}>: {}", topic, data.escape_debug());
-        sink.write(data.as_bytes())?;
+        sink.write_all(data.as_bytes())?;
         Ok(())
     };
 
@@ -285,7 +285,7 @@ impl Action {
 
         let mut reader = std::io::BufReader::new(ro);
 
-        const TEMPORARY: &'static str = ".spellcheck.tmp";
+        const TEMPORARY: &str = ".spellcheck.tmp";
 
         // Avoid issues when processing multiple files in parallel
         let tmp_name = TEMPORARY.to_owned() + uuid::Uuid::new_v4().to_string().as_str();
@@ -304,15 +304,26 @@ impl Action {
         let mut content = String::with_capacity(2e6 as usize);
         reader.get_mut().read_to_string(&mut content)?;
 
-        apply_patches(
-            bandaids.into_iter().map(|x| Patch::from(x)),
-            content.as_str(), // FIXME for efficiency, correct_lines should integrate with `BufRead` instead of a `String` buffer
-            &mut writer,
-        )?;
+        {
+            let th = crate::TinHat::on();
 
-        writer.flush()?;
+            apply_patches(
+                bandaids.into_iter().map(|x| Patch::from(x)),
+                content.as_str(), // FIXME for efficiency, correct_lines should integrate with `BufRead` instead of a `String` buffer
+                &mut writer,
+            )?;
 
-        fs::rename(tmp, path)?;
+            writer.flush()?;
+            // Required for windows support, which does not allow
+            // to move a file while it is opened, see
+            // <https://github.com/drahnr/cargo-spellcheck/issues/251>
+            drop(writer);
+            drop(reader);
+            fs::rename(tmp, path)?;
+
+            // Writing for this file is done, unblock the signal handler.
+            drop(th);
+        }
 
         Ok(())
     }
