@@ -1,17 +1,17 @@
 //! Reflow documentation comments to a desired line width.
 //!
-//! Note that for commonmark this might not be possible with links.
-//! The reflow is done based on the comments no matter the content.
+//! Note that for commonmark this might not be possible with links. The reflow
+//! is done based on the comments no matter the content.
 
-use crate::errors::*;
+use crate::errors::{eyre, Result};
 
 use crate::checker::Checker;
-use crate::documentation::{CheckableChunk, Documentation};
+use crate::documentation::CheckableChunk;
 #[cfg(debug_assertions)]
 use crate::util::load_span_from;
 use crate::util::{byte_range_to_char_range, byte_range_to_char_range_many, sub_char_range};
 
-use crate::{CommentVariant, ContentOrigin, Detector, Range, Span, Suggestion, SuggestionSet};
+use crate::{CommentVariant, ContentOrigin, Detector, Range, Span, Suggestion};
 
 use pulldown_cmark::{Event, Options, Parser, Tag};
 
@@ -20,10 +20,16 @@ pub use crate::config::ReflowConfig;
 mod iter;
 pub use iter::{Gluon, Tokeneer};
 
-use rayon::prelude::*;
-
 #[derive(Debug)]
-pub struct Reflow;
+pub struct Reflow {
+    config: ReflowConfig,
+}
+
+impl Reflow {
+    pub fn new(config: ReflowConfig) -> Result<Self> {
+        Ok(Self { config })
+    }
+}
 
 impl Checker for Reflow {
     type Config = ReflowConfig;
@@ -32,38 +38,26 @@ impl Checker for Reflow {
         Detector::Reflow
     }
 
-    fn check<'a, 's>(docu: &'a Documentation, config: &Self::Config) -> Result<SuggestionSet<'s>>
+    fn check<'a, 's>(
+        &self,
+        origin: &ContentOrigin,
+        chunks: &'a [CheckableChunk],
+    ) -> Result<Vec<Suggestion<'s>>>
     where
         'a: 's,
     {
-        let suggestions = docu
-            .par_iter()
-            .try_fold::<SuggestionSet, Result<SuggestionSet>, _, _>(
-                || SuggestionSet::new(),
-                |mut acc, (origin, chunks)| {
-                    'c: for chunk in chunks {
-                        match chunk.variant() {
-                            CommentVariant::SlashAsterisk
-                            | CommentVariant::SlashAsteriskAsterisk
-                            | CommentVariant::SlashAsteriskEM => {
-                                continue 'c;
-                            }
-                            _ => {}
-                        }
-                        let suggestions = reflow(origin, chunk, config)?;
-                        acc.extend(origin.clone(), suggestions);
-                    }
-                    Ok(acc)
-                },
-            )
-            .try_reduce(
-                || SuggestionSet::new(),
-                |mut a, b| {
-                    a.join(b);
-                    Ok(a)
-                },
-            )?;
-        Ok(suggestions)
+        let mut acc = Vec::with_capacity(chunks.len());
+        for chunk in chunks {
+            match chunk.variant() {
+                CommentVariant::SlashAsterisk
+                | CommentVariant::SlashAsteriskAsterisk
+                | CommentVariant::SlashAsteriskEM => continue,
+                _ => {}
+            }
+            let suggestions = reflow(&origin, chunk, &self.config)?;
+            acc.extend(suggestions);
+        }
+        Ok(acc)
     }
 }
 
@@ -134,12 +128,14 @@ pub fn extract_delimiter<'s>(s: &'s str) -> Option<&'static str> {
 
 /// Reflows a parsed commonmark paragraph contained in `s`.
 ///
-/// Returns the `Some(replacement)` string if a reflow has been performed and `None` otherwise.
+/// Returns the `Some(replacement)` string if a reflow has been performed and
+/// `None` otherwise.
 ///
-/// `range` denotes the range of the paragraph of interest in the top-level `CheckableChunk`.
-/// `unbreakable_ranges` contains all ranges of words/sequences which must not be split during
-/// the reflow. They are relative to the top-level `CheckableChunk` similar to `range`. The indentation
-/// vector contains the indentation for each line in `s`.
+/// `range` denotes the range of the paragraph of interest in the top-level
+/// `CheckableChunk`. `unbreakable_ranges` contains all ranges of
+/// words/sequences which must not be split during the reflow. They are relative
+/// to the top-level `CheckableChunk` similar to `range`. The indentation vector
+/// contains the indentation for each line in `s`.
 fn reflow_inner<'s>(
     s: &'s str,
     range: Range,
@@ -315,9 +311,9 @@ impl<'s> Indentation<'s> {
 
 /// Collect reflown Paragraphs in a `Vec` of `Suggestions`.
 ///
-/// Note: Leading spaces are skipped by the CommonMark parser,
-/// which implies for `///` and `//!`, the paragraph for the first
-/// line starting right after `/// ` (note the space here).
+/// Note: Leading spaces are skipped by the CommonMark parser, which implies for
+/// `///` and `//!`, the paragraph for the first line starting right after `///
+/// ` (note the space here).
 ///
 ///
 /// Returns: end of processed range and Suggestion, if reflow happened.
@@ -440,7 +436,8 @@ fn store_suggestion<'s>(
     ))
 }
 
-/// Parses a `CheckableChunk` and performs the re-wrapping on contained paragraphs.
+/// Parses a `CheckableChunk` and performs the re-wrapping on contained
+/// paragraphs.
 fn reflow<'s>(
     origin: &ContentOrigin,
     chunk: &'s CheckableChunk,
