@@ -12,7 +12,7 @@ macro_rules! verify_reflow_inner {
             .is_test(true)
             .try_init();
 
-        const CONTENT: &'static str = fluff_up!($( $line ),+);
+        const CONTENT: &str = fluff_up!($( $line ),+);
         let docs = Documentation::load_from_str(ContentOrigin::TestEntityRust, CONTENT, false);
         assert_eq!(docs.entry_count(), 1);
         let chunks = docs.get(&ContentOrigin::TestEntityRust).expect("Must contain dummy path");
@@ -107,12 +107,11 @@ macro_rules! reflow_content {
                         bandaid
                     })
             })
-            .map(|x| crate::Patch::from(x))
-            .collect::<Vec<crate::Patch>>();
+            .map(|x| crate::Patch::from(x));
 
         let mut dest = Vec::with_capacity($content.len() * 3 / 2);
         crate::action::apply_patches(
-            patches.into_iter(),
+            patches,
             $content,
             &mut dest,
         ).expect("Patches always apply nicely. qed");
@@ -274,12 +273,12 @@ fn reflow_indentations() {
         .is_test(true)
         .try_init();
 
-    const CONTENT: &'static str = r#"
+    const CONTENT: &str = r#"
     /// 🔴 🍁
     /// 🤔
     struct Fluffy {};"#;
 
-    const EXPECTED: &'static str = r#"🔴
+    const EXPECTED: &str = r#"🔴
     /// 🍁
     /// 🤔"#;
 
@@ -299,29 +298,27 @@ fn reflow_indentations() {
         reflow(&ContentOrigin::TestEntityRust, chunk, &CONFIG).expect("Reflow is wokring. qed");
 
     let suggestion = suggestion_set
-        .iter()
-        .next()
+        .first()
         .expect("Contains one suggestion. qed");
 
     dbg!(load_span_from(&mut CONTENT.as_bytes(), suggestion.span).unwrap());
 
     let replacement = suggestion
         .replacements
-        .iter()
-        .next()
+        .first()
         .expect("There is a replacement. qed");
     assert_eq!(replacement.as_str(), EXPECTED);
 }
 
 #[test]
 fn reflow_doc_indentations() {
-    const CONTENT: &'static str = r##"
+    const CONTENT: &str = r##"
     #[doc = r#"A comment with indentation that spans over
                 two lines and should be rewrapped.
             "#]
     struct Fluffy {};"##;
 
-    const EXPECTED: &'static str = r##"A comment with indentation"#]
+    const EXPECTED: &str = r##"A comment with indentation"#]
     #[doc = r#"that spans over two lines and"#]
     #[doc = r#"should be rewrapped."##;
 
@@ -340,14 +337,12 @@ fn reflow_doc_indentations() {
         reflow(&ContentOrigin::TestEntityRust, chunk, &cfg).expect("Reflow is working. qed");
 
     let suggestions = suggestion_set
-        .iter()
-        .next()
+        .first()
         .expect("Contains one suggestion. qed");
 
     let replacement = suggestions
         .replacements
-        .iter()
-        .next()
+        .first()
         .expect("There is a replacement. qed");
     assert_eq!(replacement.as_str(), EXPECTED);
 }
@@ -381,8 +376,7 @@ fn reflow_split_one_into_three() {
 
 #[test]
 fn reflow_markdown_two_paragraphs() {
-    const CONTENT: &'static str =
-        "/// Possible __ways__ to run __rustc__ and request various parts of LTO.
+    const CONTENT: &str = "/// Possible __ways__ to run __rustc__ and request various parts of LTO.
 ///
 /// Some more text after the newline which **represents** a paragraph";
 
@@ -411,14 +405,13 @@ fn reflow_markdown_two_paragraphs() {
     };
 
     let suggestion_set =
-        reflow(&ContentOrigin::TestEntityRust, &chunk, &cfg).expect("Reflow is working. qed");
+        reflow(&ContentOrigin::TestEntityRust, chunk, &cfg).expect("Reflow is working. qed");
 
     for (sug, expected) in suggestion_set.iter().zip(expected) {
         assert_eq!(sug.replacements.len(), 1);
         let replacement = sug
             .replacements
-            .iter()
-            .next()
+            .first()
             .expect("An replacement exists. qed");
 
         assert_eq!(replacement.as_str(), expected);
@@ -453,14 +446,10 @@ With a second part that is fine"#
     for (chunk, expect) in chunks.iter().zip(expected) {
         let suggestion_set =
             reflow(&ContentOrigin::TestEntityRust, chunk, &cfg).expect("Reflow is working. qed");
-        let sug = suggestion_set
-            .iter()
-            .next()
-            .expect("Contains a suggestion. qed");
+        let sug = suggestion_set.first().expect("Contains a suggestion. qed");
         let replacement = sug
             .replacements
-            .iter()
-            .next()
+            .first()
             .expect("An replacement exists. qed");
         assert_eq!(replacement.as_str(), expect);
     }
@@ -492,8 +481,7 @@ fn reflow_sole_markdown() {
         max_line_length: 60,
     };
 
-    const CONTENT: &'static str =
-        "# Possible __ways__ to run __rustc__ and request various parts of LTO.
+    const CONTENT: &str = "# Possible __ways__ to run __rustc__ and request various parts of LTO.
 
 A short line but long enough such that we reflow it. Yada lorem ipsum stuff needed.
 
@@ -557,8 +545,7 @@ multiline. Fullstop."#,
         assert_eq!(sug.replacements.len(), 1);
         let replacement = sug
             .replacements
-            .iter()
-            .next()
+            .first()
             .expect("Reflow always provides a replacement string. qed");
 
         assert_eq!(sug.span, expected_span);
@@ -595,7 +582,7 @@ fn reflow_check_span() {
         max_line_length: 27,
     };
 
-    const CONTENT: &'static str = "/// A comment as we have many here and we will always
+    const CONTENT: &str = "/// A comment as we have many here and we will always
 /// have.
 struct Fff;
 ";
@@ -630,7 +617,7 @@ struct Fff;
 #[test]
 fn reflow_readme() {
     // TODO reduce this to the minimal failing test case
-    const README: &'static str = include_str!("../../README.md");
+    const README: &str = include_str!("../../README.md");
 
     reflow_content!(80usize break ContentOrigin::TestEntityCommonMark, README => ok);
 }
@@ -660,7 +647,7 @@ Yada
 "# ] );
 }
 
-const MINIFIED_README: &'static str = r###"# cargo-spellcheck
+const MINIFIED_README: &str = r###"# cargo-spellcheck
 
 [![crates.io](https://img.source/cargo_spellcheck.svg)](https://crates.io)
 
@@ -723,7 +710,7 @@ of `0`.
 
 #[test]
 fn reflow_crlf() {
-    const INPUT: &'static str = "        /// cargo spellcheck can be configured with `-m <code>` to return a non-zero return code.\r\n        struct Foo {}";
+    const INPUT: &str = "        /// cargo spellcheck can be configured with `-m <code>` to return a non-zero return code.\r\n        struct Foo {}";
     println!("{:?}", INPUT);
     reflow_content!(40usize break ContentOrigin::TestEntityRust, INPUT
     => patches [
